<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>TreeWindow</name>
    <message>
        <location filename="../treewindow.ui" line="14"/>
        <source>Panel DOM Tree</source>
        <translation>Δέντρο πίνακα DOM</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="63"/>
        <location filename="../treewindow.ui" line="96"/>
        <source>Property</source>
        <translation>Ιδιότητα</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="68"/>
        <source>Value</source>
        <translation>Τιμή</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="76"/>
        <source>All properties</source>
        <translation>Όλες οι ιδιότητες</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="101"/>
        <source>Type</source>
        <translation>Τύπος</translation>
    </message>
    <message>
        <location filename="../treewindow.ui" line="106"/>
        <source>String value</source>
        <translation>Τιμή συμβολοσειράς</translation>
    </message>
</context>
</TS>
